#!/bin/sh

cd /opt/handsoff
run-standalone.sh python handsoff.py

exit 0
